/*
 * Aurora Droid
 * Copyright (C) 2019, Rahul Kumar Patel <whyorean@gmail.com>
 *
 * Aurora Droid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Aurora Droid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Aurora Droid.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.aurora.adroid.adapter;

import android.content.Context;
import android.content.Intent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.fragment.app.FragmentManager;
import androidx.recyclerview.widget.RecyclerView;

import com.aurora.adroid.activity.DetailsActivity;
import com.aurora.adroid.activity.AuroraActivity;
import com.aurora.adroid.GlideApp;
import com.aurora.adroid.R;
import com.aurora.adroid.model.App;
import com.aurora.adroid.util.DatabaseUtil;
import com.aurora.adroid.util.Util;

import org.apache.commons.lang3.StringUtils;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;
import java.util.concurrent.TimeUnit;

import butterknife.BindView;
import butterknife.ButterKnife;

public class ClusterAppsAdapter extends RecyclerView.Adapter<ClusterAppsAdapter.ViewHolder> {

    private List<App> appList = new ArrayList<>();
    private Context context;

    public ClusterAppsAdapter(Context context) {
        this.context = context;
    }

    public void clearData() {
        appList.clear();
        notifyDataSetChanged();
    }

    public void addData(List<App> appList) {
        this.appList.clear();
        this.appList = appList;
        notifyDataSetChanged();
    }

    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        LayoutInflater inflater = LayoutInflater.from(parent.getContext());
        View view = inflater.inflate(R.layout.item_cluster, parent, false);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder holder, int position) {
        final App app = appList.get(position);
        holder.txtTitle.setText(app.getName());
        holder.txtExtra.setText(Util.getDateFromMilli(app.getLastUpdated()));
        holder.itemView.setOnClickListener(v -> {
            Intent intent = new Intent(context, DetailsActivity.class);
            intent.putExtra("INTENT_APK_FILE_NAME", app.getPackageName());
            context.startActivity(intent);
        });
        GlideApp
                .with(context)
                .asBitmap()
                .load(DatabaseUtil.getImageUrl(app))
                .placeholder(R.drawable.ic_placeholder)
                .into(holder.imgIcon);
    }

    private FragmentManager getFragmentManager() {
        return ((AuroraActivity) context).getSupportFragmentManager();
    }

    private StringBuilder getLastUpdated(Long lastUpdated) {
        return new StringBuilder()
                .append(TimeUnit.MILLISECONDS.toDays(Calendar.getInstance().getTimeInMillis() - lastUpdated))
                .append(StringUtils.SPACE)
                .append("days ago");
    }

    @Override
    public int getItemCount() {
        return appList.size();
    }

    public class ViewHolder extends RecyclerView.ViewHolder {
        @BindView(R.id.img_icon)
        ImageView imgIcon;
        @BindView(R.id.txt_app)
        TextView txtTitle;
        @BindView(R.id.txt_extra)
        TextView txtExtra;

        ViewHolder(@NonNull View itemView) {
            super(itemView);
            ButterKnife.bind(this, itemView);
        }
    }

}
